#ifndef _CHISQ_H
#define _CHISQ_H

double pochisq(double x, int df);
double critchi(double p, int df);

#endif
